.. _github-stats-3-3-1:

GitHub Stats for Matplotlib 3.3.1
=================================

GitHub stats for 2020/07/16 - 2020/08/13 (tag: v3.3.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 25 issues and merged 73 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/56?closed=1>`__

The following 17 authors contributed 131 commits.

* Antony Lee
* Ben Root
* Bruno Beltran
* David Stansby
* Elliott Sales de Andrade
* Isuru Fernando
* jbhopkins
* Jody Klymak
* Jouni K. Seppänen
* Lee Johnston
* linchiwei123
* Neilzon Viloria
* Ryan May
* Thomas A Caswell
* Tim Hoffmann
* Tom Neep
* Yichao Yu

GitHub issues and pull requests:

Pull Requests (73):

* :ghpull:`18243`: Fix reshape list of strings
* :ghpull:`18240`: Backport PR #18235 on branch v3.3.x
* :ghpull:`18239`: Backport PR #18233 on branch v3.3.x (Fix cibuildwheel trigger condition.)
* :ghpull:`18235`: FIX: check we have a back button in tk toolbar before we touch it
* :ghpull:`18233`: Fix cibuildwheel trigger condition.
* :ghpull:`18231`: Backport PR #18224 on branch v3.3.x (Try out cibuildwheel.)
* :ghpull:`18224`: Try out cibuildwheel.
* :ghpull:`18230`: Backport PR #18225 on branch v3.3.x (Use certifi when downloading bundled build requirements.)
* :ghpull:`18225`: Use certifi when downloading bundled build requirements.
* :ghpull:`18229`: Backport PR #18219 on branch v3.3.x (Fixes an issue where WxAgg NavigationToolbar2 broke custom toolbars)
* :ghpull:`18219`: Fixes an issue where WxAgg NavigationToolbar2 broke custom toolbars
* :ghpull:`18228`: Backport PR #18227 on branch v3.3.x (Set pipefail when running flake8 linter.)
* :ghpull:`18227`: Set pipefail when running flake8 linter.
* :ghpull:`18215`: Backport PR #18185 on branch v3.3.x (FIX: fix reading from http/https urls via imread)
* :ghpull:`18214`: Backport PR #18184 on branch v3.3.x (Go back to checking figures for their manager in destroy.)
* :ghpull:`18185`: FIX: fix reading from http/https urls via imread
* :ghpull:`18184`: Go back to checking figures for their manager in destroy.
* :ghpull:`18183`: Backport PR #17995 on branch v3.3.x (Avoid using Bbox machinery in Path.get_extents; special case polylines.)
* :ghpull:`18182`: Backport PR #17994 on branch v3.3.x (Special case degree-1 Bezier curves.)
* :ghpull:`18179`: Backport PR #18175 on branch v3.3.x (Downgrade symbol substitution log to info level.)
* :ghpull:`18177`: Backport PR #18092 on branch v3.3.x (Use same Make as FreeType's configure to build it.)
* :ghpull:`18174`: Backport PR #18167 on branch v3.3.x (Catch Pandas AssertionError on deprecated multidimensional indexing. Closes #18158)
* :ghpull:`18176`: Backport PR #18173 on branch v3.3.x (Fix the return value of Axes.get_navigate_mode.)
* :ghpull:`18175`: Downgrade symbol substitution log to info level.
* :ghpull:`18092`: Use same Make as FreeType's configure to build it.
* :ghpull:`18173`: Fix the return value of Axes.get_navigate_mode.
* :ghpull:`18167`: Catch Pandas AssertionError on deprecated multidimensional indexing. Closes #18158
* :ghpull:`18162`: Backport PR #18156 on branch v3.3.x (Fix IndexError when using scatter3d and depthshade=False)
* :ghpull:`18156`: Fix IndexError when using scatter3d and depthshade=False
* :ghpull:`18153`: Backport PR #18142 on branch v3.3.x (Fix nbagg in Chrome 84)
* :ghpull:`18146`: Backport PR #17989 on branch v3.3.x (gtk/tk: Ensure no flicker when hovering over images.)
* :ghpull:`18142`: Fix nbagg in Chrome 84
* :ghpull:`18147`: Backport PR #18136 on branch v3.3.x (Sort 3d sizes along with other properties)
* :ghpull:`18136`: Sort 3d sizes along with other properties
* :ghpull:`17989`: gtk/tk: Ensure no flicker when hovering over images.
* :ghpull:`18102`: Fix linting on v3.3.x
* :ghpull:`18111`: Backport PR #18089 on branch v3.3.x
* :ghpull:`18109`: Backport PR #18093 on branch v3.3.x (Improve saving animated GIF with ffmpeg)
* :ghpull:`18089`: Revert "Convert adjust_bbox to use ExitStack."
* :ghpull:`18093`: Improve saving animated GIF with ffmpeg
* :ghpull:`18104`: Backport PR #18101 on branch v3.3.x (FIX: catch all multi-dim warnings pandas)
* :ghpull:`18101`: FIX: catch all multi-dim warnings pandas
* :ghpull:`18091`: ci: Fix linting being ignored by reviewdog
* :ghpull:`18083`: Backport PR #18079 on branch v3.3.x (Set shading='auto' if invalid value passed to pcolormesh)
* :ghpull:`18079`: Set shading='auto' if invalid value passed to pcolormesh
* :ghpull:`18067`: Backport PR #17956 on branch v3.3.x (ENH: Add version check for mac sdk version)
* :ghpull:`17956`: ENH: Add version check for mac sdk version
* :ghpull:`18053`: Backport PR #18021: FIX: update num2julian and julian2num
* :ghpull:`18021`: FIX: update num2julian and julian2num
* :ghpull:`18041`: Backport PR #18038 on branch v3.3.x (FIX: use internal _set_postion, not external)
* :ghpull:`18038`: FIX: use internal _set_postion, not external
* :ghpull:`18036`: Backport PR #18030 on branch v3.3.x (Fix PolyCollection.set_verts optimization.)
* :ghpull:`18030`: Fix PolyCollection.set_verts optimization.
* :ghpull:`18032`: Backport PR #18026 on branch v3.3.x (FIX: Be sure matplotlib.backends is imported before we use it)
* :ghpull:`18026`: FIX: Be sure matplotlib.backends is imported before we use it
* :ghpull:`18027`: Backport PR #17981 on branch v3.3.x (gtk: Fix ``draw`` on unmapped windows.)
* :ghpull:`17981`: gtk: Fix ``draw`` on unmapped windows.
* :ghpull:`18024`: Backport PR #17963 on branch v3.3.x (TST: Ignore deprecations when switching backends.)
* :ghpull:`18023`: Backport PR #18014 on branch v3.3.x (Fix flipped paths in non-writable config dir warning.)
* :ghpull:`17963`: TST: Ignore deprecations when switching backends.
* :ghpull:`18014`: Fix flipped paths in non-writable config dir warning.
* :ghpull:`18008`: Backport PR #17969 on branch v3.3.x (Honor ``'Date': None`` in metadata)
* :ghpull:`18009`: Backport PR #17982 on branch v3.3.x (BF: for degenerate polygons, add CLOSEPOLY vertex)
* :ghpull:`17982`: BF: for degenerate polygons, add CLOSEPOLY vertex
* :ghpull:`17969`: Honor ``'Date': None`` in metadata
* :ghpull:`17995`: Avoid using Bbox machinery in Path.get_extents; special case polylines.
* :ghpull:`17994`: Special case degree-1 Bezier curves.
* :ghpull:`17990`: Manual backport of pr 17983 on v3.3.x
* :ghpull:`17984`: Backport PR #17972 on branch v3.3.x (Fix PyPy compatiblity issue)
* :ghpull:`17985`: Backport PR #17976 on branch v3.3.x (Fixed #17970 - Docstrings should not accessed with -OO)
* :ghpull:`17983`: FIX: undeprecate and update num2epoch/epoch2num
* :ghpull:`17976`: Fixed #17970 - Docstrings should not accessed with -OO
* :ghpull:`17972`: Fix PyPy compatiblity issue

Issues (25):

* :ghissue:`18234`: _reshape_2D function behavior changed, breaks hist for some cases in 3.3.0
* :ghissue:`18232`: different behaviour between 3.3.0 and 3.2.2 (and earlier) for ploting in a Tk canvas
* :ghissue:`18212`: Updated WxAgg NavigationToolbar2 breaks custom toolbars
* :ghissue:`18129`: Error reading png image from URL with imread in matplotlib 3.3
* :ghissue:`18163`: Figure can not be closed if it has associated Agg canvas
* :ghissue:`17974`: Major speed regression introduced in "plt.bar" definition clipping between 3.0.3 and 3.3.0.
* :ghissue:`17998`: New warning: Substituting symbol \perp from STIXGeneral
* :ghissue:`18057`: Fails to install in FreeBSD
* :ghissue:`18150`: Regression in get_navigate_mode() return value
* :ghissue:`18158`: X-axis that is Pandas Series time zone aware timestamps raises AssertionError
* :ghissue:`18037`: Scatter3D: depthshade=False causes IndexError for Tkinter when plotting more than one point.
* :ghissue:`18169`: When running python with -OO option, an empty matplotlib docstring causes an exception.
* :ghissue:`18165`: fig.colorbar() and using bbox='tight' in PDF export mess up figure dimensions
* :ghissue:`18132`: A simple 3D scatter plot with %matplotlib notebook is not working
* :ghissue:`18135`: Point size array in the Axes3D scatter() does not follow the same order as in the data points
* :ghissue:`18061`: 3.3.0 regression in png backend with colorbar()
* :ghissue:`18076`: pcolormesh + gourand shading + polar axes is broken
* :ghissue:`18010`: 3.3.0: possible regression/bug with DateFormatter?
* :ghissue:`18033`: v. 3.3.0:  horizontal colorbar broken
* :ghissue:`18017`: Optimisation in set_verts causes error if ``verts`` have irregular sizes
* :ghissue:`18022`: AttributeError: module 'matplotlib' has no attribute 'backends'
* :ghissue:`18011`: Confusing error message when home config directory not writable
* :ghissue:`17975`: Computing the bounding box of a degenerate polygon throws an error
* :ghissue:`17968`: Setting ``Date`` metadata to ``None`` does not remove the date metadata from the SVG file
* :ghissue:`17970`: AttributeError when using PYTHONOPTIMIZE (due to stripped docstring)
